@@ -1,8 +1,8 @@
 'use strict';
 angular.module('monitoring.controllers', [])
-    .controller('monitoringController', function ($scope, $http, $timeout) {
+    .controller('monitoringController', function ($scope, $http, $timeout, $location) {
          $scope.fetchStatus = function() {
-            $http({method: 'GET', url: '/monitoring/status'}).
+            $http({method: 'GET', url: $location.absUrl().concat('status')}).
                 success(function(data, status, headers, config) {
                   // this callback will be called asynchronously
                   // when the response is available
@@ -119,6 +119,16 @@ angular.module('monitoring.controllers', [])
         }
     })
 
+angular.module('monitoring.filters', [])
+    .filter('spacedim', function () {
+        return function(text) {
+            if (typeof text == "string")
+                return text;
+            return JSON.stringify(text).split(',').join(', ');
+        }
+    })
+
+
 function uniqueNames(input, key) {
     var unique = {};
     var uniqueList = [];
@@ -142,4 +152,4 @@ function getIcon(status) {
         return '/static/monitoring/img/ok-icon.png'
     else if (status === 'chicklet-notfound')
         return '/static/monitoring/img/notfound-icon.png'
-}
\ No newline at end of file
+}
